Crate focus_tracker

Crate focus_tracker 

Structs

FocusTracker
FocusTrackerBuilder
Use builder syntax to set the inputs and finish with build().
FocusTrackerConfig
FocusTrackerTrackFocusBuilder
Use builder syntax to set the inputs and finish with call().
FocusedWindow
IconConfig
IgnoreRule
A single ignore predicate: matches when both the process-name and window-title predicates match (logical AND).
IgnoreRules
A set of ignore rules. A focus event is ignored when any rule matches.

Enums

FocusTrackerError
ProcessNameMatch
Predicate over FocusedWindow::process_name.
WindowTitleMatch
Predicate over FocusedWindow::window_title.

Functions

focused_document_url
Returns the document URL of the focused window for the given OS process, when the platform and the application expose one.

Type Aliases

FocusTrackerResult